@@ -16,7 +16,6 @@
 #' @references Bi J., Bennett K.P. (2003). Regression error characteristic curves, in: Twentieth
 #' International Conference on Machine Learning (ICML-2003), Washington, DC.
 #'
-#' @import ggplot2
 #'
 #' @seealso \code{\link{plot_roc}, \link{plot_rroc}}
 #'
@@ -27,18 +26,17 @@
 #' model_lm <- lm(life_length ~ ., data = dragons)
 #'
 #' # use DALEX package to wrap up a model into explainer
-#' exp_lm <- DALEX::explain(model_lm, data = dragons, y = dragons$life_length)
+#' lm_audit <- audit(model_lm, data = dragons, y = dragons$life_length)
 #'
 #' # validate a model with auditor
-#' library(auditor)
-#' mr_lm <- model_residual(exp_lm)
+#' mr_lm <- model_residual(lm_audit)
 #' plot_rec(mr_lm)
 #' plot(mr_lm, type = "rec")
 #'
 #' library(randomForest)
 #' model_rf <- randomForest(life_length~., data = dragons)
-#' exp_rf <- DALEX::explain(model_rf, data = dragons, y = dragons$life_length)
-#' mr_rf <- model_residual(exp_rf)
+#' rf_audit <- audit(model_rf, data = dragons, y = dragons$life_length)
+#' mr_rf <- model_residual(rf_audit)
 #' plot_rec(mr_lm, mr_rf)
 #' plot(mr_lm, mr_rf, type = "rec")
 #'
@@ -81,6 +79,6 @@ plot_rec <- function(object, ...) {
 #' @rdname plot_rec
 #' @export
 plotREC <- function(object, ...) {
-  message("Please note that 'plotREC()' is now deprecated, it is better to use 'plot_rec()' instead.")
+  warning("Please note that 'plotREC()' is now deprecated, it is better to use 'plot_rec()' instead.")
   plot_rec(object, ...)
 }
