@@ -31,12 +31,10 @@
 #' # fit a model
 #' model_lm <- lm(life_length ~ ., data = dragons)
 #'
-#' # use DALEX package to wrap up a model into explainer
-#' exp_lm <- DALEX::explain(model_lm, data = dragons, y = dragons$life_length)
+#' lm_audit <- audit(model_lm, data = dragons, y = dragons$life_length)
 #'
 #' # validate a model with auditor
-#' library(auditor)
-#' mr_lm <- model_residual(exp_lm)
+#' mr_lm <- model_residual(lm_audit)
 #'
 #' # plot results
 #' plot_rroc(mr_lm)
@@ -44,13 +42,11 @@
 #'
 #' library(randomForest)
 #' model_rf <- randomForest(life_length~., data = dragons)
-#' exp_rf <- DALEX::explain(model_rf, data = dragons, y = dragons$life_length)
-#' mr_rf <- model_residual(exp_rf)
+#' rf_audit <- audit(model_rf, data = dragons, y = dragons$life_length)
+#' mr_rf <- model_residual(rf_audit)
 #' plot_rroc(mr_lm, mr_rf)
 #' plot(mr_lm, mr_rf, type="rroc")
 #'
-#' @import ggplot2
-#'
 #' @export
 plot_rroc <- function(object, ...) {
 
@@ -91,6 +87,6 @@ plot_rroc <- function(object, ...) {
 #' @rdname plot_rroc
 #' @export
 plotRROC <- function(object, ...) {
-  message("Please note that 'plotRROC()' is now deprecated, it is better to use 'plot_rroc()' instead.")
+  warning("Please note that 'plotRROC()' is now deprecated, it is better to use 'plot_rroc()' instead.")
   plot_rroc(object, ...)
 }
