@@ -4,11 +4,13 @@
 #' \eqn{ \sum{\#[res_i \leq simres_{i,j}] - n } }
 #' with the distinction that each element of sum is also scaled to take values from [0,1].
 #'
-#' \eqn{res_i} is a residual for i-th observation, \eqn{simres_{i,j}} is the residual of j-th simulation for i-th observation, and \eqn{n} is the number of simulations for each observation.
+#' \eqn{res_i} is a residual for i-th observation, \eqn{simres_{i,j}} is the residual of j-th simulation
+#' for i-th observation, and \eqn{n} is the number of simulations for each observation.
 #' Scores are calculated on the basis of simulated data, so they may differ between function calls.
 #'
-#' @param object An object of class \code{explainer} created with function \code{\link[DALEX]{explain}} from the DALEX package.
-#' @param ... Extra arguments passed to \link[hnp]{hnp}.
+#' @param object An object of class \code{explainer} created with function
+#'  \code{\link[DALEX]{explain}} from the DALEX package.
+#' @param ... ...
 #'
 #' @return An object of class \code{auditor_score}.
 #'
@@ -19,14 +21,12 @@
 #' model_lm <- lm(life_length ~ ., data = dragons)
 #'
 #' # create an explainer
-#' exp_lm <- DALEX::explain(model_lm, data = dragons, y = dragons$life_length)
+#' lm_audit <- audit(model_lm, data = dragons, y = dragons$life_length)
 #'
 #' # calculate score
-#' score_halfnormal(exp_lm)
+#' score_halfnormal(lm_audit)
 #'
 #'
-#' @importFrom hnp hnp
-#'
 #' @export
 
 score_halfnormal <- function(object, ...) {
@@ -62,6 +62,6 @@ calculate_score_pdf <- function(hnpObject) {
 #' @rdname score_halfnormal
 #' @export
 scoreHalfNormal <- function(object, ...) {
-  message("Please note that 'scoreHalfNormal()' is now deprecated, it is better to use 'score_halfnormal()' instead.")
+  warning("Please note that 'scoreHalfNormal()' is now deprecated, it is better to use 'score_halfnormal()' instead.")
   score_halfnormal(object, ...)
 }
