@@ -2,8 +2,11 @@
 #'
 #' @description Root Mean Square Error.
 #'
-#' @param object An object of class \code{explainer} created with function \code{\link[DALEX]{explain}} from the DALEX package.
-#' @param data New data that will be used to calcuate the score. Pass \code{NULL} if you want to use \code{data} from \code{object}.
+#' @param object An object of class \code{explainer} created with function
+#'  \code{\link[DALEX]{explain}} from the DALEX package.
+#' @param data New data that will be used to calcuate the score.
+#'  Pass \code{NULL} if you want to use \code{data} from \code{object}.
+#' @param y New y parameter will be used to calculate score.
 #' @param ... Other arguments dependent on the type of score.
 #'
 #' @return An object of class \code{auditor_score}.
@@ -15,10 +18,10 @@
 #' model_lm <- lm(life_length ~ ., data = dragons)
 #'
 #' # create an explainer
-#' exp_lm <- DALEX::explain(model_lm, data = dragons, y = dragons$life_length)
+#' lm_audit <- audit(model_lm, data = dragons, y = dragons$life_length)
 #'
 #' # calculate score
-#' score_rmse(exp_lm)
+#' score_rmse(lm_audit)
 #'
 #'
 #' @seealso \code{\link{score}}
@@ -26,11 +29,15 @@
 #' @export
 
 
-score_rmse <- function(object, data = NULL, ...) {
+score_rmse <- function(object, data = NULL, y = NULL, ...) {
   if(!("explainer" %in% class(object))) stop("The function requires an object created with explain() function from the DALEX package.")
 
   # inject new data to the explainer
-  if (!is.null(data)) object$data <- data
+  if (!is.null(data)){
+    object$data <- data
+    object$y <- y
+    object$y_hat <- object$predict_function(object$model, data)
+  }
 
   mse_results <- list(
     name = "rmse",
@@ -44,7 +51,7 @@ score_rmse <- function(object, data = NULL, ...) {
 #' @rdname score_rmse
 #' @export
 scoreRMSE<- function(object) {
-  message("Please note that 'scoreRMSE()' is now deprecated, it is better to use 'score_rmse()' instead.")
+  warning("Please note that 'scoreRMSE()' is now deprecated, it is better to use 'score_rmse()' instead.")
   score_rmse(object)
 }
 
