@@ -4,9 +4,12 @@
 #' The score value is helpful in comparing models. It is worth pointing out that results of tests like p-value makes sense only
 #' when the test assumptions are satisfied. Otherwise test statistic may be considered as a score.
 #'
-#' @param object An object of class \code{explainer} created with function \code{\link[DALEX]{explain}} from the DALEX package.
+#' @param object An object of class \code{explainer} created with function
+#'  \code{\link[DALEX]{explain}} from the DALEX package.
 #' @param variable name of model variable to order residuals.
-#' @param data New data that will be used to calcuate the score. Pass \code{NULL} if you want to use \code{data} from \code{object}.
+#' @param data New data that will be used to calcuate the score. Pass
+#'  \code{NULL} if you want to use \code{data} from \code{object}.
+#' @param y New y parameter will be used to calculate score.
 #' @param ... Other arguments dependent on the type of score.
 #'
 #' @return An object of class \code{auditor_score}.
@@ -18,18 +21,22 @@
 #' model_lm <- lm(life_length ~ ., data = dragons)
 #'
 #' # create an explainer
-#' exp_lm <- DALEX::explain(model_lm, data = dragons, y = dragons$life_length)
+#' lm_audit <- audit(model_lm, data = dragons, y = dragons$life_length)
 #'
 #' # caluclate score
-#' score_runs(exp_lm)
+#' score_runs(lm_audit)
 #'
 #' @export
 
-score_runs <- function(object, variable = NULL, data = NULL, ...) {
+score_runs <- function(object, variable = NULL, data = NULL, y = NULL, ...) {
   if(!("explainer" %in% class(object))) stop("The function requires an object created with explain() function from the DALEX package.")
 
   # inject new data to the explainer
-  if (!is.null(data)) object$data <- data
+  if (!is.null(data)){
+    object$data <- data
+    object$y <- y
+    object$y_hat <- object$predict_function(object$model, data)
+  }
 
   object <- model_residual(object)
   if(!is.null(variable)) object <- object[order(object[ ,variable]), ]
@@ -63,6 +70,6 @@ score_runs <- function(object, variable = NULL, data = NULL, ...) {
 #' @rdname score_runs
 #' @export
 scoreRuns<- function(object,  variable = NULL) {
-  message("Please note that 'scoreRuns()' is now deprecated, it is better to use 'score_runs()' instead.")
+  warning("Please note that 'scoreRuns()' is now deprecated, it is better to use 'score_runs()' instead.")
   score_runs(object, variable)
 }
